@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Open::This;
 
-our $VERSION = '0.000020';
+our $VERSION = '0.000021';
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -12,6 +12,8 @@ our @EXPORT_OK = qw(
     to_editor_args
 );
 
+use Module::Util;
+
 use Module::Runtime qw(
     is_module_name
     module_notional_filename
@@ -68,7 +70,7 @@ sub parse_text {
     # This is a loadable module.  Have this come after the local module checks
     # so that we don't default to installed modules.
     if ( !$parsed{file_name} && $parsed{is_module_name} ) {
-        my $found = _module_to_filename($text);
+        my $found = Module::Util::find_installed($text);
         if ($found) {
             $parsed{file_name} = $found;
         }
@@ -112,16 +114,6 @@ sub maybe_get_url_from_parsed_text {
     return $clone;
 }
 
-sub _module_to_filename {
-    my $name = shift;
-    return undef unless ( defined $name && is_module_name($name) );
-    try { require_module($name) };
-
-    my $notional = module_notional_filename($name);
-
-    return exists $INC{$notional} ? $INC{$notional} : undef;
-}
-
 sub to_editor_args {
     return editor_args_from_parsed_text( parse_text(@_) );
 }
@@ -342,7 +334,7 @@ Open::This - Try to Do the Right Thing when opening files
 
 =head1 VERSION
 
-version 0.000020
+version 0.000021
 
 =head1 DESCRIPTION
 
